@@ -415,7 +415,7 @@ class AssetsAPI(APIClient):
             Union[Asset, AssetList]: Updated asset(s)
 
         Examples:
-            Perform a partial update on a asset, updating the description and adding a new field to metadata::
+            Perform a partial update on an asset, updating the description and adding a new field to metadata::
 
                 >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import AssetUpdate
@@ -426,6 +426,17 @@ class AssetsAPI(APIClient):
                 >>> another_update = AssetUpdate(id=1).description.set(None)
                 >>> res2 = c.assets.update(another_update)
 
+            Remove the metadata on an asset::
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import AssetUpdate
+                >>> c = CogniteClient()
+                >>> my_update = AssetUpdate(id=1).metadata.add({"key": "value"})
+                >>> res1 = c.assets.update(my_update)
+                >>> another_update = AssetUpdate(id=1).metadata.set(None)
+                >>> # The same result can be achieved with:
+                >>> another_update2 = AssetUpdate(id=1).metadata.set({})
+                >>> res2 = c.assets.update(another_update)
+
             Attach labels to an asset::
 
                 >>> from cognite.client import CogniteClient
@@ -518,11 +529,10 @@ class AssetsAPI(APIClient):
         asset = self.retrieve(id=id, external_id=external_id)
         if asset is None:
             return AssetList([], self._cognite_client)
-        subtree = self._get_asset_subtree(AssetList([asset]), current_depth=0, depth=depth)
-        subtree._cognite_client = self._cognite_client
-        return subtree
+        subtree = self._get_asset_subtree([asset], current_depth=0, depth=depth)
+        return AssetList(subtree, self._cognite_client)
 
-    def _get_asset_subtree(self, assets: AssetList, current_depth: int, depth: Optional[int]) -> AssetList:
+    def _get_asset_subtree(self, assets: List, current_depth: int, depth: Optional[int]) -> List:
         subtree = assets
         if depth is None or current_depth < depth:
             children = self._get_children(assets)
@@ -530,7 +540,7 @@ class AssetsAPI(APIClient):
                 subtree.extend(self._get_asset_subtree(children, current_depth + 1, depth))
         return subtree
 
-    def _get_children(self, assets: AssetList) -> AssetList:
+    def _get_children(self, assets: List) -> List:
         ids = [a.id for a in assets]
         tasks = []
         chunk_size = 100
@@ -541,7 +551,7 @@ class AssetsAPI(APIClient):
         )
         tasks_summary.raise_compound_exception_if_failed_tasks()
         res_list = tasks_summary.results
-        children = AssetList([])
+        children = []
         for res in res_list:
             children.extend(res)
         return children
