@@ -3,7 +3,7 @@ from typing import *
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
-from cognite.client.data_classes import Relationship, RelationshipFilter, RelationshipList
+from cognite.client.data_classes import Relationship, RelationshipFilter, RelationshipList, RelationshipUpdate
 from cognite.client.data_classes.labels import LabelFilter
 
 
@@ -63,6 +63,7 @@ class RelationshipsAPI(APIClient):
         labels: LabelFilter = None,
         limit: int = None,
         fetch_resources: bool = False,
+        chunk_size: int = None,
     ) -> Generator[Union[Relationship, RelationshipList], None, None]:
         """Iterate over relationships
 
@@ -82,6 +83,7 @@ class RelationshipsAPI(APIClient):
             created_time (Dict[str, int]): Range to filter the field for. (inclusive)
             active_at_time (Dict[str, int]): Limits results to those active at any point within the given time range, i.e. if there is any overlap in the intervals [activeAtTime.min, activeAtTime.max] and [startTime, endTime], where both intervals are inclusive. If a relationship does not have a startTime, it is regarded as active from the begining of time by this filter. If it does not have an endTime is will be regarded as active until the end of time. Similarly, if a min is not supplied to the filter, the min will be implicitly set to the beginning of time, and if a max is not supplied, the max will be implicitly set to the end of time.
             labels (LabelFilter): Return only the resource matching the specified label constraints.
+            chunk_size (int, optional): Number of Relationships to return in each chunk. Defaults to yielding one relationship at a time.
 
         Yields:
             Union[Relationship, RelationshipList]: yields Relationship one by one if chunk is not specified, else RelationshipList objects.
@@ -114,7 +116,11 @@ class RelationshipsAPI(APIClient):
             )
 
         return self._list_generator(
-            method="POST", limit=limit, filter=filter, other_params={"fetchResources": fetch_resources}
+            method="POST",
+            limit=limit,
+            filter=filter,
+            chunk_size=chunk_size,
+            other_params={"fetchResources": fetch_resources},
         )
 
     def __iter__(self) -> Generator[Relationship, None, None]:
@@ -142,7 +148,7 @@ class RelationshipsAPI(APIClient):
 
             Get relationship by external id:
 
-                >>> from cognite.client.beta import CogniteClient
+                >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>> res = c.relationships.retrieve(external_id="1")
         """
@@ -165,7 +171,7 @@ class RelationshipsAPI(APIClient):
 
             Get relationships by external id::
 
-                >>> from cognite.client.beta import CogniteClient
+                >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>> res = c.relationships.retrieve_multiple(external_ids=["abc", "def"])
         """
@@ -220,13 +226,13 @@ class RelationshipsAPI(APIClient):
 
             List relationships::
 
-                >>> from cognite.client.beta import CogniteClient
+                >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>> relationship_list = c.relationships.list(limit=5)
 
             Iterate over relationships::
 
-                >>> from cognite.client.beta import CogniteClient
+                >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>> for relationship in c.relationships:
                 ...     relationship # do something with the relationship
@@ -295,10 +301,9 @@ class RelationshipsAPI(APIClient):
 
             Create a new relationship specifying object type and external id for source and target::
 
-                >>> from cognite.client.beta import CogniteClient
+                >>> from cognite.client import CogniteClient
                 >>> from cognite.client.data_classes import Relationship
                 >>> c = CogniteClient()
-                >>> assets = c.assets.retrieve_multiple(id=[1,2,3])
                 >>> flowrel1 = Relationship(external_id="flow_1", source_external_id="source_ext_id", source_type="asset", target_external_id="target_ext_id", target_type="event", confidence=0.1, data_set_id=1234)
                 >>> flowrel2 = Relationship(external_id="flow_2", source_external_id="source_ext_id", source_type="asset", target_external_id="target_ext_id", target_type="event", confidence=0.1, data_set_id=1234)
                 >>> res = c.relationships.create([flowrel1,flowrel2])
@@ -311,6 +316,56 @@ class RelationshipsAPI(APIClient):
 
         return self._create_multiple(items=relationship)
 
+    def update(
+        self, item: Union[Relationship, RelationshipUpdate, List[Union[Relationship, RelationshipUpdate]]]
+    ) -> Union[Relationship, RelationshipList]:
+        """`Update one or more relationships <https://docs.cognite.com/api/v1/#operation/updateRelationships>`_
+        Currently, a full replacement of labels on a relationship is not supported (only partial add/remove updates). See the example below on how to perform partial labels update.
+
+        Args:
+            item (Union[Relationship, RelationshipUpdate, List[Union[Relationship, RelationshipUpdate]]]): Relationships(s) to update
+
+        Returns:
+            Union[Relationship, RelationshipsList]: Updated relationship(s)
+
+        Examples:
+            Update a data set that you have fetched. This will perform a full update of the data set::
+
+                >>> from cognite.client import CogniteClient
+                >>> c = CogniteClient()
+                >>> rel = c.relationships.retrieve(external_id="flow1")
+                >>> rel.confidence = 0.75
+                >>> res = c.relationships.update(rel)
+
+            Perform a partial update on a relationship, setting a source_external_id and a confidence::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import RelationshipUpdate
+                >>> c = CogniteClient()
+                >>> my_update = RelationshipUpdate(external_id="flow_1").source_external_id.set("alternate_source").confidence.set(0.97)
+                >>> res1 = c.relationships.update(my_update)
+                >>> # Remove an already set optional field like so
+                >>> another_update = RelationshipUpdate(external_id="flow_1").confidence.set(None)
+                >>> res2 = c.relationships.update(another_update)
+
+            Attach labels to a relationship::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import RelationshipUpdate
+                >>> c = CogniteClient()
+                >>> my_update = RelationshipUpdate(external_id="flow_1").labels.add(["PUMP", "VERIFIED"])
+                >>> res = c.relationships.update(my_update)
+
+            Detach a single label from a relationship::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import RelationshipUpdate
+                >>> c = CogniteClient()
+                >>> my_update = RelationshipUpdate(external_id="flow_1").labels.remove("PUMP")
+                >>> res = c.relationships.update(my_update)
+        """
+        return self._update_multiple(items=item)
+
     def delete(self, external_id: Union[str, List[str]]) -> None:
         """`Delete one or more relationships. <https://docs.cognite.com/api/v1/#operation/deleteRelationships>`_
 
@@ -324,7 +379,7 @@ class RelationshipsAPI(APIClient):
 
             Delete relationships by external id::
 
-                >>> from cognite.client.beta import CogniteClient
+                >>> from cognite.client import CogniteClient
                 >>> c = CogniteClient()
                 >>> c.relationships.delete(external_id=["a","b"])
         """
